import { DslKitCategoryResponseType, DslKitItemCreatingType, DslKitItemResponseType, DslKitItemUpdatingType, DslKitResponseType } from './kit.type';
export declare enum KitPageSizeType {
    Small = "small",
    Medium = "medium",
    Large = "large"
}
export declare enum KitType {
    Font = "fontKit",
    Icon = "iconKit",
    Dsl = "dslKit",
    Image = "imageKit",
    Video = "videoKit",
    audio = "audioKit"
}
export declare type LocalizationContents = {
    zhCN: string;
    en: string;
};
export declare type GetKitList = {
    '/kitservice/kits': {
        params: {
            pageIndex: number;
            pageSizeType: KitPageSizeType;
            type: KitType;
        };
        method: 'get';
        ignoreToken: false;
        data: {
            kitListMD5: string;
            list: {
                id: string;
                type: KitType;
                detail: {
                    name: string;
                    description: string;
                    author: string;
                    image: {
                        cover: string;
                        thumb: string;
                        banner: string;
                    };
                    preview: {
                        name: string;
                        content: string;
                    }[];
                };
                sale: {
                    purchased: boolean;
                    discount: {
                        ordinary: number;
                        member: number;
                    };
                    purchaseCount: number;
                    price: number;
                };
                content: {
                    md5: string;
                    size: number;
                    value: string;
                };
                updatedAt: string;
                createdAt: string;
                categories: {
                    id: string;
                    name: string;
                }[];
                styles: {
                    id: string;
                    name: string;
                }[];
                md5: string;
            }[];
        };
    };
};
export declare type GetKitDetail = {
    '/kitservice/kit': {
        params: {
            id: string;
        };
        method: 'get';
        ignoreToken: false;
        data: {
            id: string;
            type: KitType;
            detail: {
                name: LocalizationContents;
                description: LocalizationContents;
                author: string;
                image: {
                    cover: string;
                    thumb: string;
                    banner: string;
                };
            };
            sale: {
                discount: {
                    ordinary: number;
                    member: number;
                };
                purchaseCount: number;
                price: number;
            };
            resourceMD5: string;
            content: {
                size: number;
                value: {
                    path: string;
                };
            };
            updatedAt: string;
            categories: {
                id: string;
                name: LocalizationContents;
            }[];
            styles: {
                id: string;
                name: LocalizationContents;
            }[];
            md5: string;
        };
    };
};
export declare type GetMediaKitCategory = {
    '/kitservice/mediaKit/category': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: {
            content: {
                pixabay: {
                    image: {
                        name: string;
                    }[];
                    video: {
                        name: string;
                    }[];
                };
                pexels: {
                    image: {
                        name: string;
                    }[];
                    video: {
                        name: string;
                    }[];
                };
            };
            hash: string;
        };
    };
};
export declare type GetPurchasedFontList = {
    '/kitservice/purchased/fontList': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: {
            list: {
                categoryId: string;
                categoryName: string;
                createdAt: Date;
                updatedAt: Date;
                tags: {
                    id: string;
                    name: string;
                    createdAt: Date;
                    updatedAt: Date;
                    fonts: {
                        id: string;
                        fontFamily: string;
                        name: string;
                        url?: string;
                        createdAt: Date;
                        updatedAt: Date;
                    }[];
                }[];
            }[];
            md5: string;
        };
    };
};
export declare type GetUploadedFontList = {
    '/kitservice/uploaded/fontList': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: {
            list: {
                categoryId: string;
                categoryName: string;
                createdAt: Date;
                updatedAt: Date;
                tags: {
                    id: string;
                    name: string;
                    createdAt: Date;
                    updatedAt: Date;
                    fonts: {
                        id: string;
                        fontFamily: string;
                        name: string;
                        url?: string;
                        createdAt: Date;
                        updatedAt: Date;
                    }[];
                }[];
            }[];
            md5: string;
        };
    };
};
export declare type GetSystemFontList = {
    '/kitservice/system/fontList': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: {
            list: {
                categoryId: string;
                categoryName: string;
                createdAt: Date;
                updatedAt: Date;
                tags: {
                    id: string;
                    name: string;
                    createdAt: Date;
                    updatedAt: Date;
                    fonts: {
                        id: string;
                        fontFamily: string;
                        name: string;
                        url?: string;
                        createdAt: Date;
                        updatedAt: Date;
                    }[];
                }[];
            }[];
            md5: string;
        };
    };
};
export declare type GetDslKits = {
    '/kitservice/dslKit': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: {
            list: DslKitResponseType[];
            md5: string;
        };
    };
};
export declare type CreateDslKitModule = {
    '/kitservice/dslKitModule/create': {
        params: {
            name: string;
            type: 'page' | 'component';
            weight?: number;
            isHtmlPreview: boolean;
        };
        method: 'post';
        ignoreToken: false;
        data: {
            id: string;
        };
    };
};
export declare type UpdateDslKitModule = {
    '/kitservice/dslKitModule/update': {
        params: {
            id: string;
            name: string;
            type: 'page' | 'component';
            weight: number;
            isHtmlPreview: boolean;
        };
        method: 'post';
        ignoreToken: false;
        data: undefined;
    };
};
export declare type CreateDslKitItem = {
    '/kitservice/dslKitItem/create': {
        params: DslKitItemCreatingType;
        method: 'post';
        ignoreToken: false;
        data: DslKitItemResponseType;
    };
};
export declare type UpdateDslKitItem = {
    '/kitservice/dslKitItem/update': {
        params: DslKitItemUpdatingType;
        method: 'post';
        ignoreToken: false;
        data: DslKitItemResponseType;
    };
};
export declare type CreateDslKitCategory = {
    '/kitservice/dslKitCategory/create': {
        params: {
            name: string;
            weight?: number;
        };
        method: 'post';
        ignoreToken: false;
        data: DslKitCategoryResponseType;
    };
};
export declare type RemoveDslKit = {
    '/kitservice/dslKitRemove': {
        params: {
            type: 'kit' | 'item' | 'category';
            id: string;
        };
        method: 'post';
        ignoreToken: false;
        data: undefined;
    };
};
export declare type GetDslKitCategories = {
    '/kitservice/getDslKitCategories': {
        params: undefined;
        method: 'post';
        ignoreToken: false;
        data: {
            list: DslKitCategoryResponseType[];
        };
    };
};
export declare type UpdateDslKitCategory = {
    '/kitservice/dslKitCategory/update': {
        params: {
            id: string;
            name: string;
            weight: number;
        };
        method: 'post';
        ignoreToken: false;
        data: DslKitCategoryResponseType;
    };
};
export declare type RemoveDslKitCategory = {
    '/kitservice/dslKitCategory/remove': {
        params: {
            id: string;
        };
        method: 'post';
        ignoreToken: false;
        data: undefined;
    };
};
export declare type RemoveDslKitItem = {
    '/kitservice/dslKitItem/remove': {
        params: {
            id: string;
        };
        method: 'post';
        ignoreToken: false;
        data: undefined;
    };
};
