import type { FieldInfoType, FieldValueType, LiveObjectType, QueryFilterDetailType, QueryFilterType, TableInfoType } from 'live-data-type';
import { SortEnum } from 'live-data-type';
export declare type GetAccessInfo = {
    '/livetable/access/get': {
        params: {
            projectId: string;
        };
        method: 'post';
        ignoreToken: false;
        data: {
            appId: string;
            appKey: string;
        };
    };
};
export declare type CreateAccessInfo = {
    '/livetable/access/create': {
        params: {
            projectId: string;
        };
        method: 'post';
        ignoreToken: false;
        data: {
            appId: string;
            appKey: string;
        };
    };
};
export declare type DeleteAccessInfo = {
    '/livetable/access/delete': {
        params: {
            projectId: string;
        };
        method: 'post';
        ignoreToken: false;
        data: undefined;
    };
};
export declare type ListAccessInfo = {
    '/livetable/access/getList': {
        params: {
            projectId: string;
        };
        method: 'post';
        ignoreToken: false;
        data: {
            appId: string;
            appKey: string;
        }[];
    };
};
export declare type GetTables = {
    '/livetable/tables': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: TableInfoType[];
    };
};
export declare type SaveTable = {
    '/livetable/table': {
        params: {
            id?: string;
            tableName: string;
            fields: FieldInfoType[];
        };
        method: 'post';
        ignoreToken: false;
        data: {
            id: string;
            name: string;
            fields: FieldInfoType[];
        };
    };
};
export declare type DeleteTable = {
    '/livetable/table': {
        params: {
            tableId: string;
        };
        method: 'delete';
        ignoreToken: false;
        data: undefined;
    };
};
export declare type CreateTableItem = {
    '/livetable/data/createOne': {
        params: {
            tableId: string;
            data: LiveObjectType;
        };
        method: 'post';
        ignoreToken: true;
        data: LiveObjectType;
    };
};
export declare type DeleteTableItem = {
    '/livetable/data/delete': {
        params: {
            tableId: string;
            filter: QueryFilterType;
        };
        method: 'post';
        ignoreToken: true;
        data: {
            deletedCount: number;
        };
    };
};
export declare type UpdateTableItem = {
    '/livetable/data/update': {
        params: {
            tableId: string;
            filter: QueryFilterType;
            data: LiveObjectType;
        };
        method: 'post';
        ignoreToken: true;
        data: {
            modifiedCount: number;
        };
    };
};
export declare type CustomerFindParamsType = {
    content: {
        precondition: {
            needToken: boolean;
            queries?: QueryFilterDetailType[];
        };
        executor: {
            query: QueryFilterDetailType;
            sort?: [string, SortEnum][];
            limit?: number;
            skip?: number;
        };
    };
    executorId?: string;
    token?: string;
};
export declare type UserFindParamsType = {
    content: {
        executor: {
            query: QueryFilterDetailType;
            sort?: [string, SortEnum][];
            limit?: number;
            skip?: number;
        };
    };
};
export declare type FindTableItems = {
    '/livetable/data/find': {
        params: UserFindParamsType | CustomerFindParamsType;
        method: 'post';
        ignoreToken: true;
        data: {
            list: LiveObjectType[];
            count?: number;
        };
    };
};
export declare type SendSmsCode = {
    '/livetable/user/sendSmsCode': {
        params: {
            phone: string;
        };
        method: 'post';
        ignoreToken: true;
        data: undefined;
    };
};
export declare type CallSpecificMethod = {
    '/livetable/callSpecificMethod': {
        params: {
            method: string;
            params?: {
                [param: string]: FieldValueType;
            };
        };
        method: 'post';
        ignoreToken: true;
        data: any;
    };
};
export declare type GetSpecificMethods = {
    '/livetable/getSpecificMethods': {
        params: undefined;
        method: 'get';
        ignoreToken: false;
        data: {
            [method: string]: {
                [param: string]: string;
            };
        };
    };
};
